@@ -18,8 +18,7 @@ import os
 import re
 import six
 
-from glanceclient import exc as glance_exc
-from novaclient import exceptions as nova_exc
+
 from rally.common import logging
 from rally.common import validation
 from rally.common import yamlutils as yaml
@@ -76,6 +75,8 @@ class ImageExistsValidator(validation.Validator):
     @with_roles_ctx()
     def validate(self, context, config, plugin_cls, plugin_cfg):
 
+        from glanceclient import exc as glance_exc
+
         image_args = config.get("args", {}).get(self.param_name)
 
         if not image_args and self.nullable:
@@ -97,10 +98,10 @@ class ImageExistsValidator(validation.Validator):
                 return
         try:
             for user in context["users"]:
-                clients = user["credential"].clients()
-                image_id = openstack_types.GlanceImage.transform(
-                    clients=clients, resource_config=image_args)
-                clients.glance().images.get(image_id)
+                image_processor = openstack_types.GlanceImage(
+                    context={"admin": {"credential": user["credential"]}})
+                image_id = image_processor.pre_process(image_args, config={})
+                user["credential"].clients().glance().images.get(image_id)
         except (glance_exc.HTTPNotFound, exceptions.InvalidScenarioArgument):
             self.fail("Image '%s' not found" % image_args)
 
@@ -202,12 +203,16 @@ class FlavorExistsValidator(validation.Validator):
         return flavor
 
     def _get_validated_flavor(self, config, clients, param_name):
+
+        from novaclient import exceptions as nova_exc
+
         flavor_value = config.get("args", {}).get(param_name)
         if not flavor_value:
             self.fail("Parameter %s is not specified." % param_name)
         try:
-            flavor_id = openstack_types.Flavor.transform(
-                clients=clients, resource_config=flavor_value)
+            flavor_processor = openstack_types.Flavor(
+                context={"admin": {"credential": clients.credential}})
+            flavor_id = flavor_processor.pre_process(flavor_value, config={})
             flavor = clients.nova().flavors.get(flavor=flavor_id)
             return flavor
         except (nova_exc.NotFound, exceptions.InvalidScenarioArgument):
@@ -252,6 +257,9 @@ class ImageValidOnFlavorValidator(FlavorExistsValidator):
         self.validate_disk = validate_disk
 
     def _get_validated_image(self, config, clients, param_name):
+
+        from glanceclient import exc as glance_exc
+
         image_context = config.get("contexts", {}).get("images", {})
         image_args = config.get("args", {}).get(param_name)
         image_ctx_name = image_context.get("image_name")
@@ -274,8 +282,9 @@ class ImageValidOnFlavorValidator(FlavorExistsValidator):
                 }
                 return image
         try:
-            image_id = openstack_types.GlanceImage.transform(
-                clients=clients, resource_config=image_args)
+            image_processor = openstack_types.GlanceImage(
+                context={"admin": {"credential": clients.credential}})
+            image_id = image_processor.pre_process(image_args, config={})
             image = clients.glance().images.get(image_id)
             if hasattr(image, "to_dict"):
                 # NOTE(stpierre): Glance v1 images are objects that can be
@@ -414,11 +423,16 @@ class RequiredServicesValidator(validation.Validator):
                         "a long time and latest novaclient doesn't support "
                         "it, so we too.")
 
+        if "api_versions" in config.get("contexts", {}):
+            api_versions = config["contexts"]["api_versions"]
+        else:
+            api_versions = config.get("contexts", {}).get(
+                "api_versions@openstack", {})
+
         for service in self.services:
             # NOTE(andreykurilin): validator should ignore services configured
             # via context(a proper validation should be in context)
-            service_config = config.get("contexts", {}).get(
-                "api_versions@openstack", {}).get(service, {})
+            service_config = api_versions.get(service, {})
 
             if (service not in available_services and
                     not ("service_type" in service_config or
